#!/bin/sh

# download and package brave
# 1st version

[ $(id -u) -ne 0 ] && exec sudo -A ${0} ${@}

export TEXTDOMAIN=install_brave_gui.sh
export OUTPUT_CHARSET=UTF-8

CWD=`pwd`
export CWD

# func strings
WRONG=$(gettext 'Sorry, Brave is not supported on this architecture: ')
IMSG=$(gettext 'Please wait... checking latest versions')
ERR_TITLE=$(gettext 'Install Brave - message')
EX=$(gettext ' already exists in /mnt/home. Load it or move it! Exiting.')
TTLC=$(gettext ' needs GTK 3.0. Quit this program and install it from the package manager.')
ERR_CON=$(gettext "There seems to be a problem connecting to the Brave servers.")
IS_RET=$(gettext 'is already retrieved')
ESFS=$(gettext 'There was a problem loading ')
OKSFS1=$(gettext ' is located in ')
OKSFS2=$(gettext '. You can choose to save this for later if you wish. It will be loaded when you close this window.')
OKSFS_PM5=$(gettext '<b>IMPORTANT:</b> Since you are running in RAM, the SFS file is in your home directory. If you plan to save your session then you should choose the default <i>Recommended</i> option in the next installation window, or you can choose to install it with the <b>NOCOPY</b> option if you plan to <i>not</i> save your session or at your own discretion another location listed.')
SMSG=$(gettext ' is successfully installed! It is recommended that you run this program once a week to keep brave updated.')
SMSG_NOINST=$(gettext ' is successfully downloaded and packaged however you did not install it. Save it or install with sfs_load. It is located in ')
ARMSG=$(gettext 'The bsdtar utility, part of libarchive, is not installed. We will attempt to use rpm2cpio.')
RPMMSG=$(gettext 'The rpm2cpio utility is not installed. Attempting a hack...')
CPMSG=$(gettext 'The cpio utility is not installed. Exiting')
WMSG=$(gettext 'Please wait while the package archive is unpacked...')
MSG1=$(gettext "You can download the Brave stable version and install a squash filesystem (SFS) Puppy package.")
MSG2=$(gettext "Just hit the button and the Brave download will start")
MSG3=$(gettext "Choose if you want to run as 'root' or unprivileged user 'spot'")

	
. /etc/rc.d/PUPSTATE

TMP=/tmp
[ $PUPMODE -eq 5 ] && TMP=$HOME

# gui for messages
init_msg() {
	MSG="$1" 
	[ -z "$2" ] && GTKICON=no || GTKICON=$2
	[ -n "$3" ] && GEXTRA="`/usr/lib/gtkdialog/xml_info fixed /usr/share/pixmaps/puppy/dialog-info.svg 60 "$3"`" || GEXTRA=''
	
export ERR='<window title="'$ERR_TITLE'" icon-name="gtk-'${GTKICON}'" resizable="false">
	<vbox>
	'"`/usr/lib/gtkdialog/xml_info fixed /usr/share/pixmaps/dl_vivaldi.svg 60 "$MSG"`"' 
	<hbox><text><label>" " </label></text></hbox>
	'$GEXTRA'
	  <frame>
	    <hbox homogeneous="true">
			<button ok></button>
		</hbox>
	  </frame>
	</vbox>
</window>'
. /usr/lib/gtkdialog/xml_info gtk
gtkdialog -p ERR -c --styles=/tmp/gtkrc_xml_info.css
[ "$2" = 'yes' ] || exit 1
}

# check if an sfs is loaded
is_sfs_loaded() {
	local B_SFS_LOADED
	[ -f /tmp/sfs_load/loop_device_list ] && B_SFS_LOADED=`grep "${1}" /tmp/sfs_load/loop_device_list`
	if [ -z "$B_SFS_LOADED" ]; then
		return 1 #not loaded
	fi
	return 0
}


# check if sfs is in /mnt/home
check_sfs_exists() {
	BRS_FILE="$1"
	is_sfs_loaded $BRS_FILE && return 0
	if [ -f "/initrd/${PUP_HOME}/${BRS_FILE}" ];then
		#kill -9 $apid
		init_msg "$BRS_FILE $EX"
	fi
}

# unload
unload_sfs() {
	sfs_load
}

# download, extract and build funtions
func_dld() {
	( 
	TMP=$TMP urxvt -bg  green -fg blue --geometry 80x20+1+1 -e latest-brave.sh $1 $2
	)
}

load_sfs() {
	sfs_load +"${1}"
	return $?
}

# trap - clean up
_trap_exit() {
	cd $CWD
	killall yaf-splash >/dev/null 2>&1
	echo killed
}
trap _trap_exit EXIT

# check arch
arch=${arch:-`uname -m`}

case $arch in
	x86_64) # carry on
	;;
	*)init_msg "$WRONG $arch";;
esac


# dependencies
GTK3=''
find /usr -maxdepth 4 -type d -name 'gtk-*'|grep 'lib'|grep -q '3' && GTK3='yes'
[ "$GTK3" != 'yes' ] && init_msg "Brave Browser $TTLC" 

if type ar >/dev/null 2>&1 ; then
	AR=ar
else
	AR='busybox ar'
fi
export AR

# find icons
SFSICON=/usr/share/pixmaps/puppy/package_sfs.svg
ICONTHEME=`grep -i 'icon-theme' ~/.gtkrc-2.0|sed -e 's/^gtk-icon-theme-name = //' -e 's/\"//g'`
[ -e "/usr/share/icons/$ICONTHEME/48/mimetypes/application-x-squashfs-image.svg" ] &&\
	SFSICON="/usr/share/icons/$ICONTHEME/48/mimetypes/application-x-squashfs-image.svg"
	

# check if installed ####
# but wait..
gtkdialog-splash -close never -bg CornflowerBlue -text "$IMSG" &
export apid=$!
read zz yy CUR_STABLE_VERSION <<< $(brave-browser-stable --version 2>/dev/null)
CUR_STABLE_VERSION=${CUR_STABLE_VERSION#*.}
# get the brave URL
RELEASE_TAG_U=
GHUB=https://github.com
PAGE_0=/brave/brave-browser/releases
curl -s $GHUB/$PAGE_0 > /tmp/brave0.htm
MAX=5 # go through $MAX pages, if we don't find a release abort

cnt=0
while [ $cnt -le $MAX ]; do
	U=$(grep -m1 'Release v1' /tmp/brave${cnt}.htm | grep -o 'brave.*>Rel' | sed 's/\">Rel//')
	[ -z "$U" ] && U=$(grep ">Next<" /tmp/brave${cnt}.htm  | tr '"' '\n' | grep -o 'https.*after.*$' | tail -n1)
		cnt=$(($cnt + 1))
		#echo $cnt $U
	if echo $U | grep -q 'after=' ;then # not on 1st page
		curl -s $U > /tmp/brave${cnt}.htm
	else
		RELEASE_TAG_U=$U
		break
	fi
done
rm -f /tmp/brave*.htm
DLD_RELEASE_U=$(curl -s $GHUB/$RELEASE_TAG_U | grep -om1 '\/brave\/.*amd64\.deb')
GITHUBVER=${DLD_RELEASE_U##*\/}
GITHUBVER=${GITHUBVER%\.*}
if [ -z "$GITHUBVER" ];then # can't find it so get URL from slackbuilds as fallback
	XTRASTUFF=$(gettext '<b>INFORMATION</b>: The very latest Brave version was not found so a slightly older version is offered for download. Check again soon and a newer version will be available. ')
	PREBRAVEURL=$(curl -s https://slackbuilds.org/repository/14.2/network/brave-browser/ | grep "Source Downloads" | grep -o 'https.*rpm">' | sed 's%\">%%')
	NEW_STABLE_VERSION=$(echo $PREBRAVEURL | grep -o 'browser\-.*\.x86' | sed -e 's%\([a-z]*[a-z]\-\)%%' -e 's%\.[a-z].*$%%')
	GET_STABLE_VERSION=${NEW_STABLE_VERSION%\-*}
	NEW_STABLE_VERSION=$GET_STABLE_VERSION
	xBRAVEURL=$(echo $PREBRAVEURL | grep -o '^.*v1.*\/')
else
	XTRASTUFF=''
	GET_STABLE_VERSION=$(echo $GITHUBVER | sed -e 's/^.*browser_//' -e 's/_amd64$//') # usually later version
	NEW_STABLE_VERSION=$GET_STABLE_VERSION
	xBRAVEURL=$(echo $GHUB${DLD_RELEASE_U} | grep -o '^.*v1.*\/')
fi

[ -z "$NEW_STABLE_VERSION" ] && init_msg "$ERR_CON"

kill -9 $apid

BRAVEURL=$xBRAVEURL

# common
BGUI=''
CUR=brave-browser
VER="$CUR_STABLE_VERSION";NVER="$NEW_STABLE_VERSION"
echo N $NVER
export VERSION="$NEW_STABLE_VERSION"
# check sfs exists in /mnt/home and not loaded"
SSFS=${CUR}-${NVER}-${arch}
echo $SSFS
# this stops the program on the first match
check_sfs_exists ${SSFS}~root.sfs
check_sfs_exists ${SSFS}~spot.sfs
# check latest installed
BRAVE=true
if [ "$VER" = "$NVER" ];then
	BRAVE=false
fi
[ -n "$VER" ] && BC=false || BC=true
#check if sfs is installed
is_sfs_loaded $CUR
if [ $? -eq 0 ];then
	ICON=$SFSICON
	ACT=unload
	PROG=sfs_load
fi
# add to main gui
TBASE1=$(gettext ', an older version is installed. Uninstall it with ')
TBASE2=$(gettext ' - button on left - and run this program again later.')
if [ -n "$VER" ];then
	if [ "$VER" != "$NVER" ];then
		BGUI='<hbox space-expand="true" space-fill="true">
				<button space-expand="false" space-fill="true">
				  <input file>'$ICON'</input>
				  <width>32</width><height>32</height>
				  <action function="exit">'$ACT'</action>
				</button>
				<text use-markup="true" space-expand="true" space-fill="false" justify="2">
				  <label>"<i>'${CUR}-${VER}${TBASE1}${PROG}${TBASE2}'</i>"</label>
				</text>
			</hbox>'
	fi
else
	BGUI=''
fi
[ -n "$BGUI" ] && BGUI='<vbox space-expand="true" space-fill="false">'$BGUI'</vbox>'
####

BEST=$(gettext 'is already installed')

if [ "$BRAVE" = 'true' ]; then
	BC='true'
	BEST=''
else
	BC='false'
	MSG2=$(gettext 'Latest Brave is already installed')
fi
BI='<button image-position="top" theme-icon-size="32" tooltip-text="version '$NEW_STABLE_VERSION' '$BEST'">
			<label>Brave</label>
			<variable>btnvi</variable>
			<input file>/usr/share/pixmaps/brave.svg</input>
			<sensitive>'$BC'</sensitive>
		</button>'
# gui
export DLG='<window title="Install Brave Browser" icon-name="internet" resizable="false">
	<vbox width-request="500">
	'"`/usr/lib/gtkdialog/xml_info fixed /usr/share/pixmaps/brave.svg 60 "$XTRASTUFF $MSG1"`"' 
	  <frame>
	  <text><label>'$MSG3'</label></text>
	  <hbox homogeneous="true">
		  <pixmap>
	        <width>32</width>
			<height>32</height>
	        <input file>/usr/share/pixmaps/spot.png</input>
	      </pixmap>
	      <radiobutton tooltip-text="RECOMMENDED">
			<label>spot</label>
			<variable>RADIOBUTTON2</variable>
		  </radiobutton>
	      <pixmap>
	        <width>32</width>
			<height>32</height>
	        <input file>/usr/share/pixmaps/root.png</input>
	      </pixmap>		  
	      <radiobutton>
			<label>root</label>
			<variable>RADIOBUTTON1</variable>
		  </radiobutton>
	  </hbox>
	  </frame>
	  <frame>
	  '$BGUI'
	  <hbox space-expand="true" space-fill="false">
	    <text><label>'"$MSG2"'</label></text>
	  </hbox>
	  <hbox homogeneous="true">  
	  '$BI'
	  </hbox>
	  </frame>

	  <hbox>
	    <button cancel></button>
	  </hbox>
	</vbox>
</window>'

. /usr/lib/gtkdialog/xml_info gtk
case $1 in
 -d)echo "$DLG";;
 *)eval $(gtkdialog -p DLG --styles=/tmp/gtkrc_xml_info.css);;
esac

echo $EXIT $RADIOBUTTON1 $RADIOBUTTON2
case $EXIT in
	unload)unload_sfs
	exec $0;;
	Brave)
		ZVER=$GET_STABLE_VERSION
		;;
	*)exit;;
esac
[ "$RADIOBUTTON1" == 'true' ] && TAG='~root' \
 || TAG='~spot'

# download
TMP=$TMP urxvt -bg  green -fg blue --geometry 80x20+1+1 -e latest-brave.sh $TAG $ZVER $BRAVEURL/brave-browser_${ZVER}_amd64.deb
BSFS=${SSFS}${TAG}.sfs
echo $BSFS
cd $CWD
# make sure sfs package exists and load it
[ $PUPMODE -ne 5 ] && OKSFS_PM5=''
if [ -e "${TMP}/${BSFS}" ] ; then
	init_msg "${BSFS} $OKSFS1 ${TMP} $OKSFS2" yes "$OKSFS_PM5"
	load_sfs ${TMP}/${BSFS} || init_msg "$ESFS ${TMP}/${BSFS}"
fi
# announce success
	if [ -f /tmp/sfs_load/loop_device_list ] && grep -q "${BSFS}" /tmp/sfs_load/loop_device_list ; then
		init_msg "Brave $SMSG" yes
	else
		init_msg "Brave $SMSG_NOINST /tmp" yes
	fi
# END
